## Expected Behaviour

### Minimal Example Spec

## Actual Behaviour

## Steps to Reproduce

## Environment
- OS:
- Python version:
- Swagger/OpenAPI version used:
- Backend: (flex, swagger-spec-validator or openapi-spec-validator)
